﻿/*
Post-Deployment Script Template							
--------------------------------------------------------------------------------------
 This file contains SQL statements that will be appended to the build script.		
 Use SQLCMD syntax to include a file in the post-deployment script.			
 Example:      :r .\myfile.sql								
 Use SQLCMD syntax to reference a variable in the post-deployment script.		
 Example:      :setvar TableName MyTable							
               SELECT * FROM [$(TableName)]					
--------------------------------------------------------------------------------------
*/

/*******************************************************************
Set the recovery model to simple
*******************************************************************/
DECLARE @query nvarchar(100)
SET @query = 'ALTER DATABASE ' + DB_NAME() + ' SET RECOVERY SIMPLE'
EXEC sp_executesql @query
-- =============================================
-- Setup default InstallParameters for WOM Application.
-- These are critical for the mobile app to work correctly.
-- DataTypes
--  1 = Boolean
--  2 = Single Select List (dropdown list of values either from table or static list, blank option available.)
--  3 = Mulit Select List (checkbox list of  values either from table or static list)
--  4 = Numeric
--  5 = Text  (5 or any number between 7 and 98) 
--  6 = Single Select List (dropdown list of values either from table or static list, NO blank option available.)
-- 99 = Not editable.
-- =============================================
SET NOCOUNT ON;
if not exists (select * from [InstallParameter] where [ParameterId] = '@DVCFLTR')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('@DVCFLTR', '@EmployeeId', 'DO NOT MODIFY - Set by the Sync Configuration Page for Device Data Filter', 99)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EqpHstCt')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EqpHstCt', '10', 'The number of history records that will be maintained for each piece of equipment.', 4)
end
    
if not exists (select * from [InstallParameter] where [ParameterId] = 'MtrRdCt')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MtrRdCt', '10', 'The number of historical readings that will be maintained for each equipment meter.', 4)
end
    
if not exists (select * from [InstallParameter] where [ParameterId] = 'AMInspectionWOTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('AMInspectionWOTypes', 'INSP', 'Comma separated list of Job Types that are used for Inspection work orders.', 3, 'WorkOrderType')
end
    
if not exists (select * from [InstallParameter] where [ParameterId] = 'AMDeviceCompleteStatus')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('AMDeviceCompleteStatus', 'FC,C,Q', 'Comma-separated list of status code(s) which will cause a work order to be removed from the device.', 3, 'StatusAuthorization')
end
    
if not exists (select * from [InstallParameter] where [ParameterId] = 'GenGoodFinding')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('GenGoodFinding', '', 'The general finding code to use for good inspection points.', 2, 'Finding')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'GenBadFinding')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('GenBadFinding', '', 'The general finding code to use for bad inspection points.', 2, 'Finding')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ForcedSyncIntvlMult')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ForcedSyncIntvlMult', '100.0', 'Forces a new sync to occur if previous sync has been Running longer than this value x SyncIntervalMinutes', 4)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'AreaDefaultGroup')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('AreaDefaultGroup', 'Aspect', 'The default grouping on the inspection area summary screen (Aspect,Equipment,All)', 6, 'Aspect,Equipment,All')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultActivityId')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultActivityId', '10', 'The default Activity ID to use for booking labor when quick-completing a new work order.  Common values are 1 or 10.', 4)
end

update [InstallParameter] set [Description] = 'INCRLINO EAM Parameter: The value to increment line numbers for new comments and activities. Common values are 1 or 10.' where [ParameterId] = 'DefaultActivityId';

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultCompleteStatusCode')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultCompleteStatusCode', 'C', 'The default status code to automatically select on the Quick Complete and/or Closing Tab.  If user does not have status authorization to set this code, this will be ignored.', 2, 'StatusAuthorization')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultCompleteStatusCodeEnabledForQuickComplete')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultCompleteStatusCodeEnabledForQuickComplete', 'True', 'Determines if the status code will automatically be set to the DefaultCompleteStatusCode for the Quick Complete screen. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultCompleteStatusCodeEnabledForClosingTab')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultCompleteStatusCodeEnabledForClosingTab', 'False', 'Determines if the status code will automatically be set to the DefaultCompleteStatusCode for the Closing Tab screen. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SentTransactionSaveCount')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SentTransactionSaveCount', '25', 'Number of most recent non-pending transactions to save on the device', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AMAutoApproveInspections')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AMAutoApproveInspections', 'False', 'True to update route status and approve inspection results when work order is completed, False otherwise.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AMAutoShowFinding')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AMAutoShowFinding', 'False', 'True to automatically show the findings screen when an invalid inspection point is entered, otherwise False.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkSyncIntSeconds')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkSyncIntSeconds', '120', 'Interval between sync attempts to download new and updated work to the device', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'LookupSyncIntSeconds')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('LookupSyncIntSeconds', '3600', 'Interval between sync attempts to download new and updated reference data to the device', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TransactionSyncIntSeconds')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TransactionSyncIntSeconds', '60', 'Interval between sync attempts to upload transactions created on the device', 4)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultOccupationType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultOccupationType', 'N', 'Default Occupation Type', 6, 'OccupationType')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'LaborTradeFromActivity')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('LaborTradeFromActivity', 'False', 'Default Labor Trade From Activity', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DDF_Organization_UserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DDF_Organization_UserGroups', '', 'EAM User Groups which require an Organization device data filter', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DDF_Department_UserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DDF_Department_UserGroups', '', 'EAM User Groups which require a Department device data filter', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DDF_Employee_UserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DDF_Employee_UserGroups', '', 'EAM User Groups which require an Employee device data filter', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DDF_Equipment_Disabled_UserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DDF_Equipment_Disabled_UserGroups', '', 'EAM User Groups which do not require Equipment data on the device', 5)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'QuarantineEmail_Default')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('QuarantineEmail_Default', 'change@me.com', 'The default email address for quarantined device transactions, can be a comma separated list', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'QualMethodType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('QualMethodType', '', 'Comma separated list of inspection methods that are qualitative.', 3, 'MethodCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'QuantMethodType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('QuantMethodType', '', 'Comma separated list of inspection methods that are quantitative', 3, 'MethodCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'UseStarDeptEquipment')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('UseStarDeptEquipment', 'False', 'True/False to send Equipment in the * department to the device when the device data filter is @Department.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'UseStarOrgEquipment')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('UseStarOrgEquipment', 'False', 'True/False to send Equipment in the * organization to the device when the device data filter is @Organization.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DeviceAttachmentTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DeviceAttachmentTypes', 'PDF,HTML,JPG,BMP,PNG,TXT,DOC,DOCX', 'Comma separated list of file types that can be downloaded for viewing on a device.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TabletAttachmentTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TabletAttachmentTypes', 'PDF,HTML,JPG,BMP,PNG,TXT,DOC,DOCX', 'Comma separated list of file types that can be downloaded for viewing on a tablet', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ForceEquipmentDownloadForEmployeeFilter')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ForceEquipmentDownloadForEmployeeFilter', 'True', 'Set to True/False to force/not force all Equipment records to be downloaded on every sync when using the Employee filter.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ForceEquipmentDownloadForEmployeeFilterTables')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ForceEquipmentDownloadForEmployeeFilterTables', 'Equipment,EquipmentMeter,EquipmentMeterReading,EquipmentUdf,Comment', 'Comma-separated list of equipment-related tables to force to download for employee filter.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AnchorSetbackMinutes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AnchorSetbackMinutes', '5', 'When running integrations, set the anchor back by this number of minutes to make sure time-sensitive changes are not missed.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ESignatureEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ESignatureEnabled', 'False', 'Indicates if E-Signature Support is enabled for the Advanced Mobile system.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SnapshotSyncClientTimeoutMilliseconds')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SnapshotSyncClientTimeoutMilliseconds', '300000', 'Sets the client timeout (ms) for snapshot (re-initialize) sync requests. (AM default is 300000, .NET default is 100000)', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'IncrementalSyncClientTimeoutMilliseconds')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('IncrementalSyncClientTimeoutMilliseconds', '300000', 'Sets the client timeout (ms) for incremental (non-re-initialize) sync requests. (AM default is 300000, .NET default is 100000)', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WOHeaderUserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WOHeaderUserGroups', '', 'Determines the groups that are allowed to update work order headers', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisableWOHeaderJobType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DisableWOHeaderJobType', '', 'Determines the job types that do not allow work order header updates', 3, 'WorkOrderType')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'HiddenNewWOFields')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('HiddenNewWOFields', '', 'Determines the fields that are hidden on a new work order', 3, 'Class,Problem')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'VerifyNoOpenActivities')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('VerifyNoOpenActivities',
     'False',
     'When True, completion is only allowed if there are no open activities on the work order.', 1)
end 

if not exists (select * from [InstallParameter] where [ParameterId] = 'NewWODepartmentFromUser')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('NewWODepartmentFromUser',
     'False',
     'When True sets the new work order department to the user''s department', 1)
end 

if not exists (select * from [InstallParameter] where [ParameterId] = 'PreSyncCheckRecordCount')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('PreSyncCheckRecordCount', '0', 'When non-zero checks the record limit count pre-incremental sync to determine if a device re-init is required', 4)
end 

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisplayQualitiveInspectionPoints')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DisplayQualitiveInspectionPoints', 'False', 'When False hides qualitative inspection point input boxes', 1)
end 

if not exists (select * from [InstallParameter] where [ParameterId] = 'AllowRemoveDocument')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AllowRemoveDocument', 'True', 'When true, allows user to remove a document from a work order.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EnableOutOfServiceOnInspection')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EnableOutOfServiceOnInspection', 'False', 'When true, allows user to flag an asset as out of service during an inspection', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DeleteChildWOOnParentComplete')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DeleteChildWOOnParentComplete', 'False', 'When true, deletes all child work orders when the parent is completed', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ChecklistEAM1012Mode')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ChecklistEAM1012Mode', 'False', 'When true, uses the 10.1.2+ EAM check list mode instead of comments for checklists', 1)
end

-------------------------------------------------------------------------------
-- Custom Fields & UDFs options
-------------------------------------------------------------------------------
		
if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkCustomFieldsShown')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkCustomFieldsShown', '', 'Comma separated list of subset of Work Order Custom Fields to be displayed in Advanced Mobile', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EquipmentCustomFieldsShown')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EquipmentCustomFieldsShown', '', 'Comma separated list of subset of Equipment Custom Fields to be displayed in Advanced Mobile', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkUserDefFFieldsShown')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkUserDefFFieldsShown', '', 'Comma separated list of subset of Work Order UDFs to be displayed in Advanced Mobile', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EquipmentUserDefFieldsShown')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EquipmentUserDefFieldsShown', '', 'Comma separated list of subset of Equipment UDFs to be displayed in Advanced Mobile.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkUDFEditable')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkUDFEditable', 'true', 'True to allow users to update Work Order Custom Fields & UDFs, False otherwise', 1)
end

declare @pValue nvarchar(400)
select @pValue = [ParameterValue] FROM [InstallParameter] where [ParameterId] = 'WorkFieldsEditable'
if @pValue is not null
begin
	update [InstallParameter] 
	set [ParameterValue] = @pValue
    where [ParameterId] = 'WorkUDFEditable'
	delete from [InstallParameter] 
    where [ParameterId] = 'WorkFieldsEditable'
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EquipmentFieldsEditable')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EquipmentFieldsEditable', 'False', 'True to allow users to update Equipment Custom Fields & UDFs, False otherwise', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkRequestStatus')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('WorkRequestStatus', 'Q', 'Comma seperated list of possible work request status codes.', 3, 'StatusAuthorization')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ShowMecWorkOrdersInInbox')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ShowMecWorkOrdersInInbox', 'False', 'Displays work orders of type MEC in inbox when set to true.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SyncMecWorkOrder')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SyncMecWorkOrder', 'False', 'Includes work orders of type MEC during a mobile synchronization.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SendWorkOrderReportedDate')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SendWorkOrderReportedDate', 'False', 'If True, when creating a new work order/work request, send the Reported Date.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SendWorkOrderReportedBy')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SendWorkOrderReportedBy', 'False', 'If True, when creating a new work order/work request, send the mobile user as Reported By.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ShowIntegrationRecordCounts')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ShowIntegrationRecordCounts', 'True', 'If True, the record count for each adapter will be visible in the SyncConfig.aspx page.  If False, the record counts will not be calculated nor displayed.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspectionPointPrimarySort')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('InspectionPointPrimarySort', 'EquipmentSequence', 'Primary sort to apply on the Inspection Point grid (allowed values: "EquipmentSequence" or "SequenceNumber")', 6, 'EquipmentSequence,SequenceNumber')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderProblemCodeState')
begin
	insert into [InstallParameter]
	([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
	values
	('WorkOrderProblemCodeState', 'Visible', 'Set the Work Order Problem drop down state to Visible, Hidden, or Required.', 6, 'Visible,Hidden,Required')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderFaultCodeState')
begin
	insert into [InstallParameter]
	([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
	values
	('WorkOrderFaultCodeState', 'Visible', 'Set the Work Order Fault drop down state to Visible, Hidden, or Required.', 6, 'Visible,Hidden,Required')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderCauseCodeState')
begin
	insert into [InstallParameter]
	([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
	values
	('WorkOrderCauseCodeState', 'Visible', 'Set the Work Order Cause drop down state to Visible, Hidden, or Required.', 6, 'Visible,Hidden,Required')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderActionCodeState')
begin
	insert into [InstallParameter]
	([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
	values
	('WorkOrderActionCodeState', 'Visible', 'Set the Work Order Action drop down state to Visible, Hidden, or Required.', 6, 'Visible,Hidden,Required')
end
-- StandardComments
-- Note sure if we want these in the default install

/*
if not exists (select * from [StandardComment] where [ShortDescription] = 'Std Comm 1...')
begin
    insert into [BDSI_AM_WOM].[dbo].[StandardComment]
    ([Description], [ShortDescription])
    values
    ('Standard Comment1', 'Std Comm 1...')
end
    
if not exists (select * from [StandardComment] where [ShortDescription] = 'Std Comm 2...')
begin
    insert into [BDSI_AM_WOM].[dbo].[StandardComment]
    ([Description], [ShortDescription])
    values
    ('Standard Comment2','Std Comm 2...')
end
*/

-------------------------------------------------------------------------------
-- Maps4Apps options
-------------------------------------------------------------------------------

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsMobileCacheDirectory')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsMobileCacheDirectory', 'c:\ProgramData\Blue Dot\Maps\MobileCache.zip\', 'Set to the directory on the device where the ESRI ArcGIS Mobile mobile cache files are stored.  Command Center default location:  c:\ProgramData\Blue Dot\Maps\MobileCache.zip\', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsMaxFlashSearchResults')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsMaxFlashSearchResults', '100', 'The maximum number of search results for which the flash geometry function will be enabled in the map search results.  Higher number degrades performance.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsMaxTotalSearchResults')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsMaxTotalSearchResults', '500', 'The maximum number of search results that will be rendered on the map.  Higher number degrades performance.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinWorkOrderAttribute')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinWorkOrderAttribute', 'JobTypeCode', 'The attribute on the work order that maps to the push-pin color on the map. (JobTypeCode, StatusCode, PriorityCode)', 6, 'JobTypeCode,StatusCode,PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinAquaValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinAquaValues', 'INSP,INSP1', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as an Aqua push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinBlueValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinBlueValues', 'CAL,CAP', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as a Blue push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinGreenValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinGreenValues', '', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as a Green push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinOrangeValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinOrangeValues', 'RP', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as an Orange push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinPurpleValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinPurpleValues', 'CM,PM', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as a Purple push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsPushpinRedValues')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('Maps4AppsPushpinRedValues', 'BRKD', 'Work orders with this attribute value (see Maps4AppsPushpinWorkOrderAttribute) will be displayed as a Red push-pin. (Use comma-separated list).', 3, 'Maps4AppsPushpinWorkOrderAttribute|WorkOrderType|StatusAuthorization|PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsQueryMapForNearbyAssets')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsQueryMapForNearbyAssets', 'False', 'When creating a work order, the application will look for nearby assets by querying the map cache for objects with a GISOBJID attribute. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsQueryEamDataForNearbyAssets')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsQueryEamDataForNearbyAssets', 'True', 'When creating a work order, the application will look for nearby assets by querying the EAM Asset data for point assets with X/Y defined. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsGisObjectId')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsGisObjectId', 'GISOBJID', 'The name of the field that relates eam objects to map objects.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'Maps4AppsUseGisObjectId')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('Maps4AppsUseGisObjectId', 'True', 'When True, pass the GisObjectId. When False, pass the AssetId for identifying assets in map data.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ESignatureEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ESignatureEnabled', 'False', 'When True, prompt user for e-signature, otherwise False.', 1)
end
if not exists (select * from [InstallParameter] where [ParameterId] = 'ESignatureLicenseKey')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ESignatureLicenseKey', '', 'License Key for ESignature', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EnableInboxQuickComplete')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EnableInboxQuickComplete', 'True', 'True to display quick complete option on Inbox. False to hide option on Inbox. (Tablet Only)', 1)
end
if not exists (select * from [InstallParameter] where [ParameterId] = 'AutoDownloadDocuments')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AutoDownloadDocuments', 'False', 'When True, automatically download work order documents to each device.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EnableParts')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EnableParts', 'True', 'True to display parts from Inbox and parts tab in details. False to hide option on Inbox and Details view.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultTabletInboxFilter')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultTabletInboxFilter', 'AssignTo', 'The default work order filter on the inbox. (AssignTo, Department, OverDue, Today, Scheduled, All)', 6, 'AssignTo,Department,OverDue,Today,Scheduled,All')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AutoDownloadPrintDocuments')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AutoDownloadPrintDocuments', 'False', 'When True, automatically download work order documents marked ''Print with Work Order.''', 1)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'DeviceAttachmentMaxSize')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DeviceAttachmentMaxSize', '5', 'The maximum document size in MB allowed to be uploaded or downloaded to a handheld.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TabletAttachmentMaxSize')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TabletAttachmentMaxSize', '5', 'The maximum document size in MB allowed to be uploaded or downloaded to a tablet/pc', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'FilterWorkByTrade')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('FilterWorkByTrade', 'False', 'When true, only show work orders matching the user''s trade.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderCompleteFieldsShown')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkOrderCompleteFieldsShown', '', 'Comma delimited list of udf elements to show on work order complete.', 5)
end
if not exists (select * from [InstallParameter] where [ParameterId] = 'SearchLikeEAM')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SearchLikeEAM', 'False', 'True to have searches automatically filtered by the on screen value.  Otherwise False', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'SearchSingleSelect')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('SearchSingleSelect', 'False', 'True to have lookup select with one click instead of two. Otherwise False', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisableCharacterByCharacterSearch')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DisableCharacterByCharacterSearch', 'False', 'Disables a search each time a character is entered to enhance barcode scanner performance', 1)
end
if not exists (select * from [InstallParameter] where [ParameterId] = 'CameraApplicationPath')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('CameraApplicationPath', 'C:\Windows\System32\mspaint.exe', 'File system path for the camera application using the | character to optionally add command parameters after the application path.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultPhotoPath')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultPhotoPath', '%USERMYPICTURESPATH%', 'Path where photos are saved from the camera application.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkPage')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkPage', 'WSJOBS', 'The page name of the Job screen to use. Defaults to WSJOBS if no value is provided.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EditableAttachmentFileExtensions')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('EditableAttachmentFileExtensions', 'DOC,DOCX,XLS,XLSX,TXT', 'Comma delimited list of file extensions that can be edited and reattched from the device (e.g. "DOC,XLS,TXT")', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisableWOStatusChangeJobTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DisableWOStatusChangeJobTypes', 'MTR,ADM', 'Comma delimited list of work order job types. Work Order Status change is not allowed for these type of work orders.', 3, 'WorkOrderType')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'OnlyDisplayAssignedADMWorkOrders')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('OnlyDisplayAssignedADMWorkOrders', 'True', 'When true, only ADM work orders that are assigned to the current empmloyee are displayed. When false, all ADM work orders are displayed.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterWorkOrderJobTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('MeterWorkOrderJobTypes', 'MTR', 'Comma delimited list of work order job types for Meter jobs. Recording labor is not allowed for a work order with one of these job types.', 3, 'WorkOrderType')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisallowedNewWorkOrderTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DisallowedNewWorkOrderTypes', 'MTR,PM,INSP,ADM', 'List of job types which are not available for new job creation in Advanced Mobile.', 3, 'WorkOrderType')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'UseEquipmentAssignTo')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('UseEquipmentAssignTo', 'True', 'When true, if a new work order is not assigned, assign it to the Assign To associated with the piece of Equipment.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'PartQuantityMaxValue')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('PartQuantityMaxValue', '0', 'Defines the maximum value entering part transaction quantities (0 for unlimited).', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssignWOUserGroups')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssignWOUserGroups', '', 'Defines the list of user groups allowed to reassign work orders.', 5)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'DocumentCleanupIntervalDays')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DocumentCleanupIntervalDays', '7', 'Then number of days to wait before removing orphaned documents attachments on the device.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultNewWorkOrderStatusCode')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultNewWorkOrderStatusCode', '', 'Default status code for new work orders', 2, 'StatusAuthorization' )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultNewWorkOrderStandardWorkOrder')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultNewWorkOrderStandardWorkOrder', '', 'Default standard work order for new work orders', 2, 'StandardWorkOrder' )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ForcePartValidation')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ForcePartValidation', 'False', 'Forces validation for entered part ID', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'ReturnAnyParts')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('ReturnAnyParts', 'False', 'When true allows the return of any part regardless of quantities issued', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisableNewWorkOrder')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DisableNewWorkOrder', 'False', 'When true hides the create work order button on the inbox', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AllowEquipmentChange')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AllowEquipmentChange', 'False', 'When true enables changing the equipment on a work order', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterReadingWorkOrdersEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MeterReadingWorkOrdersEnabled', 'False', 'When true enables creating work orders for adhoc meter readings', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterReadingWorkOrderType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MeterReadingWorkOrderType', 'MILEAGE', 'Defines the work order type used when creating work orders from adhoc meter readings', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterReadingWorkOrderStatus')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MeterReadingWorkOrderStatus', 'C', 'Defines the work order status used when creating work orders from adhoc meter readings', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterReadingWorkOrderUdfFields')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MeterReadingWorkOrderUdfFields', 'UDFCHAR30,UDFCHAR29,UDFCHAR28,UDFCHAR27', 'Defines the work order UDFs used when creating work orders from adhoc meter readings', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'PrintWithDocument')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('PrintWithDocument', 'False', 'Indicates whether comments should be flagged Print With Document', 1 )
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TombstoneRetentionDays')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TombstoneRetentionDays', '7', 'Number of days tombstone records will be retained before purge.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'QuarantineRetentionDays')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('QuarantineRetentionDays', '60', 'Number of days quarantine records will be retained before purge.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultWorkOrderEntryPoint')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('DefaultWorkOrderEntryPoint', 'Activity', 'Default work order entry point (WO Details or Activity)', 6, 'Activity,Details')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'LaborTimerStartStopOption')
begin
	insert into [InstallParameter]
	([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
	values
	('LaborTimerStartStopOption', 'Timer Enabled and Start/Stop Enabled', 'Show the Start and Stop fields on the Labor entry view.', 6, 'Timer Disabled and Start/Stop Disabled,Timer Enabled and Start/Stop Enabled,Timer Disabled and Start/Stop Enabled' )
end

--if not exists (select * from [InstallParameter] where [ParameterId] = 'SubmitLaborToEAM')
--begin
    --insert into [InstallParameter]
    --([ParameterId], [ParameterValue], [Description], [DataType])
    --values
    --('SubmitLaborToEAM',
     --'True',
     --'True to allow pass labor to EAM. False to save labor locally only', 1)
--end

-------------------------------------------------------------------------------
-- Start Timesheet options
-------------------------------------------------------------------------------

if not exists (select * from [InstallParameter] where [ParameterId] = 'TimesheetWeekStartDay')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('TimesheetWeekStartDay', '1', 'First day of the timesheet week, where Sunday=0,Monday=1,Tuesday=2....,Saturday=6. Defaults to Monday.', 2, '0,1,2,3,4,5,6')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TimesheetViewEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TimesheetViewEnabled', 'False', 'True to display timesheet view. False to hide option on Inbox view.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TimesheetEntriesEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TimesheetEntriesEnabled', 'False', 'True to allow new non-work order labor to be booked on timesheet view. False to present read-only view', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TimesheetHistoryNumWeeks')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('TimesheetHistoryNumWeeks', '2', 'Number of historical weeks of labor that can be viewed or updated in timesheet view.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'TimeSheetDefaultOccupationType')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('TimeSheetDefaultOccupationType', 'X', 'Default Occupation Type for non-work-order labor entered on Timesheet view', 2, 'OccupationType')
end

-------------------------------------------------------------------------------
-- End Timesheet Options
-------------------------------------------------------------------------------

-- Manually merged from BDSAustralia 4fb7f3fc5a6eb810874589b43fa7c2dea155cc36
if not exists (select * from [InstallParameter] where [ParameterId] = 'OnHoldStatus')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('OnHoldStatus', 'H', 'Comma-separated list of status code(s) which are On Hold, which will require that a value is selected in the field defined in OnHoldUdf.', 3, 'StatusAuthorization')
end
-- Manually merged from BDSAustralia 4fb7f3fc5a6eb810874589b43fa7c2dea155cc36
if not exists (select * from [InstallParameter] where [ParameterId] = 'OnHoldUdf')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('OnHoldUdf', '', 'Work Order UDF which which should be checked for On Hold reason. e.g. udfchar05', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EquipmentSearchOption')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('EquipmentSearchOption', '3', 'How equipment can be searched. 1 = Basic, 2 = Advanced, 3 = All', 6, '1,2,3')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'EquipmentSearchOrganization')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('EquipmentSearchOrganization', 'Default', 'Which organizations are searched for online equipment search. (Default = User default organization, All = All Organizations)', 6, 'Default,All')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MeterReadingEquipmentClasses')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('MeterReadingEquipmentClasses', '', 'A comma delimited list of equipment classes that should be used to limit the equipment available for adhoc meter readings.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspBypassFinding')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('InspBypassFinding', '', 'The general finding code to used to bypass inspection points.', 2, 'Finding')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspBypassFindingValueDefault')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspBypassFindingValueDefault', '', 'The value to set to the inspection point when the InspBypassFinding is selected for qualitative points.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspGenBadFindingValueDefault')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspGenBadFindingValueDefault', '', 'The value to set to the inspection point when the GenBadFinding is selected for qualitative points.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspGenGoodFindingValueDefault')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspGenGoodFindingValueDefault', '', 'The value to set to the inspection point when the GenGoodFinding is selected for qualitative points.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspApplyFindingValueDefaults')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspApplyFindingValueDefaults', 'False', 'Determines if the finding default values are applied for qualitative inspection points. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspBypassAvailable')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspBypassAvailable', 'False', 'Determines if the bypass option is available for qualitative inspection points. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderDetailEditFields')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('WorkOrderDetailEditFields', '', 'Comma separated list of work order detail fields that should allow editing. (Description,StatusCode,JobTypeCode,PriorityCode,ProblemCode,AssignedToEmployeeId,LocationId,ClassId)', 3,'Description,StatusCode,JobTypeCode,PriorityCode,ProblemCode,AssignedToEmployeeId,LocationId,ClassId')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspSubFindPointTypeFilter')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspSubFindPointTypeFilter', 'False', 'Determines if sub findings are filtered by point type. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspSubFindPointTypeFilterPad')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspSubFindPointTypeFilterPad', '0', 'When InspSubFindPointTypeFilter is True, the number of charaters to pad the PointType when applying the filter.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspSubFindTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('InspSubFindTypes', 'N', 'Determines if general or non-general finding codes are used for sub-findings. (A = All, G = General Only, N = Non-General Only)', 3, 'A,G,N')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspCommentRequired')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspCommentRequired', 'True', 'Determines if the user must enter a comment for a failed inspection point. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspCopyCommentsToNewWorkOrder')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspCopyCommentsToNewWorkOrder', 'False', 'Determines if the user must enter a comment for a failed inspection point. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultLanguage')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultLanguage', 'EN', 'The default language code that will be used if the users language is unknown.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AttachmentFileExtensions2007')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AttachmentFileExtensions2007', 'DOCX,XLSX', 'Comma delimited list of file extensions that are for Office 2007 and later for IE10 compatibility (e.g. "DOCX,XLSX")', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'DefaultLanguageWorkOrder')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DefaultLanguageWorkOrder', 'EVNT', 'Work Order type for comments. Defaults to EVNT.', 5)
end     

if not exists (select * from [InstallParameter] where [ParameterId] = 'DisableStatusChangeForOpenInspections')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('DisableStatusChangeForOpenInspections', 'True', 'True to disable work order status changes if the work order has any open inspection points remaining. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspectionsPopupWarningEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspectionsPopupWarningEnabled', 'True', 'True to enable popup messages for confirming recorded inspection values out of critical min/max range. (True/False)', 1)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'InspectionsPopupConfirmationMessage')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspectionsPopupConfirmationMessage', 'Inspection Point finding is out of range. Please contact the night supervisor.', 'If the InspectionsPopupWarningEnabled is true, then if the user confirms the value entered, display this message.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspectionsEquipmentSearchEnabled')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspectionsEquipmentSearchEnabled', 'True', 'True to enable equipment search on the Inspection Point equipment grouping. (True/False)', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'FileUploadWhitelist')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('FileUploadWhitelist', 'JPG,BMP,PNG,GIF', 'Comma separated list of file types that can be uploaded.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderAutoAssign')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('WorkOrderAutoAssign', 'False', 'True to auto assign a new work order to the current employee. (True/False)', 1)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetDefaultClass')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetDefaultClass', '', 'The default class,org to use when creating new assets. e.g (CLASS1,ORG1)', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetDefaultStatus')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetDefaultStatus', 'I', 'The default Status code to use when creating new assets.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetDisabledStatusCodes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetDisabledStatusCodes', 'C', 'Comma delimited list of asset status codes which are disabled in Advanced Mobile for Add Asset.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetMultiStatusUpdateList')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('AssetMultiStatusUpdateList', 'I,ITD', 'Comma delimited list of asset status codes which are available for Multiple Asset Update in Advanced Mobile.', 3, 'StatusAuthorization')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspectionsShowCompletedInspections')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspectionsShowCompletedInspections', 'False', 'True to automatically check the show completed inspection checkbox.', 1)
END

if not exists (select * from [InstallParameter] where [ParameterId] = 'InspUseBypassAsSkipOption')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('InspUseBypassAsSkipOption', 'False', 'Please enable InspBypassAvailable for this feature to work. Application will display bypass option for both quantitative and qualitative methods. If selected no comment is required, no work order generated checked.', 1)
END

if not exists (select * from [InstallParameter] where [ParameterId] = 'PartsAllowedTransactionTypes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('PartsAllowedTransactionTypes', 'PLAN,RESERVE,ISSUE,RETURN', 'The transaction types for Parts that are allowed.', 3, 'PLAN,RESERVE,ISSUE,RETURN')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetMultiEditSessionMax')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetMultiEditSessionMax', '100', 'The number of assets that can be scanned per mulit-edit session.', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetTopContainerField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetTopContainerField', 'udfchar05', 'Defines the equipment UDF used for storing the asset Top Container, e.g. udfchar05', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetContainerField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetContainerField', 'udfchar06', 'Defines the equipment UDF used for storing the asset Container, e.g. udfchar06', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetTrackIdField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetTrackIdField', 'udfchar01', 'Defines the equipment UDF used for storing the asset Track ID, e.g. udfchar01', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetTagField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetTagField', 'udfchar07', 'Defines the equipment UDF used for storing the Asset Tontainer, e.g. udfchar07', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetLocationField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetLocationField', 'udfchar21', 'Defines the equipment UDF used for storing the asset location, e.g. udfchar21', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetOperationsAllowed')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('AssetOperationsAllowed', 'Add,Edit,Verification,Move', 'The asset operations that are allowed on the device.', 3,'Add,Edit,Verification,Move,ContainerList')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetAutoNumber')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetAutoNumber', 'false', 'AUTOANUM Eam Install Parameter: True to auto number assets.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetSiteAuditFilter')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetSiteAuditFilter', '', 'Secondary filter for site audit', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetSiteAuditTagPrefixes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetSiteAuditTagPrefixes', '', 'Asset tag prefixes to show by default', 5)
end


if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetSiteAuditLastAuditDateField')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetSiteAuditLastAuditDateField', '', 'User defined field for storing the last audit date.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetSiteAuditAllowMove')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetSiteAuditAllowMove', 'True', 'Allow site audit to move asset locations.', 1)
END

if not exists (select * from [InstallParameter] where [ParameterId] = 'AssetPositionLabelText')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('AssetPositionLabelText', 'Position:', 'Text to be displayed for position field.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'MultiOrgDeviceDataFilter')
begin
	insert into [InstallParameter]
	    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
		('MultiOrgDeviceDataFilter', '', 'Allows for sync and lookup of data from both the * and other orgs.', 5)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'NonStarCommonOrg')
begin 
	insert into [InstallParameter]
	    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
	    ('NonStarCommonOrg', 'false', 'Allows for sync of data when a non common org exists.', 1)
end		

if not exists (select * from [InstallParameter] where [ParameterId] = 'WorkOrderPriorityCodes')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType], [DataSource])
    values
    ('WorkOrderPriorityCodes', 'ALL', 'Comma delimited list of work order priority codes.', 3, 'PriorityCode')
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'AllowWorkOrderChecklistClose')
begin 
	insert into [InstallParameter]
	    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
	    ('AllowWorkOrderChecklistClose', 'True', 'Allow work orders with activities containing outstanding checklist items to be closed.', 1)
end		

if not exists (select * from [InstallParameter] where [ParameterId] = 'RedirectWorkOrderWithChecklistsDefaultEntry')
begin 
	insert into [InstallParameter]
	    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
	    ('RedirectWorkOrderWithChecklistsDefaultEntry', 'True', 'Redirect the default work order entry point to the activities tab for WOs with checklists.', 1)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'RfidTransmitPower')
begin
    insert into [InstallParameter]
    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
    ('RfidTransmitPower', '220', 'Determines the power of the RFID reader. Between 0-250 Default 220', 4)
end

if not exists (select * from [InstallParameter] where [ParameterId] = 'RedirectWorkOrderWithChecklistsDefaultEntry')
begin 
	insert into [InstallParameter]
	    ([ParameterId], [ParameterValue], [Description], [DataType])
    values
	    ('RedirectWorkOrderWithChecklistsDefaultEntry', 'True', 'Redirect the default work order entry point to the activities tab for WOs with checklists.', 1)
END

-------------------------------------------------------------------------------
-- Remove depricated install parameters
-------------------------------------------------------------------------------

if exists (select * from [InstallParameter] where [ParameterId] = 'DisableMeterRollover')
begin
    delete from [InstallParameter] where [ParameterId] = 'DisableMeterRollover'
end

if exists (select * from [InstallParameter] where [ParameterId] = 'HideTimer')
begin
    delete from InstallParameter where ParameterId = 'HideTimer';    
end

if exists (select * from [InstallParameter] where [ParameterId] = 'ShowStartStopLabor')
begin
    delete from InstallParameter where ParameterId = 'ShowStartStopLabor';    
end

-- =============================================
-- Script Template
-- =============================================

-------------------------------------------------------------------------------
-- Comment - Organization - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@OrganizationId', 'I', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6), @EmployeeId nvarchar(15),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType = ''OBJ'' AND EntityId LIKE ''%#%'' AND SUBSTRING(EntityId, charindex (''#'', EntityId)+1, LEN(EntityId)) IN (@OrganizationId, ''*'') 
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Assigned Work order comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Equipment History Closing Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
INNER JOIN WorkOrder on EquipmentHistory.EquipmentId = WorkOrder.EquipmentId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Activity Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language
')
END

-------------------------------------------------------------------------------
-- Comment - Organization - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@OrganizationId', 'U', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6), @EmployeeId nvarchar(15),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType = ''OBJ'' AND EntityId LIKE ''%#%'' AND SUBSTRING(EntityId, charindex (''#'', EntityId)+1, LEN(EntityId)) IN (@OrganizationId, ''*'') 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Assigned Work order comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Equipment History Closing Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
INNER JOIN WorkOrder on EquipmentHistory.EquipmentId = WorkOrder.EquipmentId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Activity Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language')
END

-------------------------------------------------------------------------------
-- Comment - Department - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@DepartmentId', 'I', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType = ''OBJ'' AND EntityId LIKE ''%#%'' AND SUBSTRING(EntityId, charindex (''#'', EntityId)+1, LEN(EntityId)) IN (@OrganizationId, ''*'') 
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
UNION
--Work order comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
INNER JOIN [UserDepartment] u
ON WorkOrder.DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE
(
	[WorkOrder].OrganizationId=@OrganizationId OR
	[WorkOrder].OrganizationId=''*''
)
--AND
--(
--	CHARINDEX('','' + [WorkOrder].DepartmentId + '','',@DepartmentId,1) > 0
--)
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
UNION
--Equipment History Closing Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] 
FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
WHERE
(
	[EquipmentHistory].OrganizationId=@OrganizationId OR
	[EquipmentHistory].OrganizationId=''*''
)
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
UNION
--Activity Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
INNER JOIN [UserDepartment] u ON [WorkOrder].DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE
(
    [WorkOrder].OrganizationId=@OrganizationId OR
    [WorkOrder].OrganizationId=''*''
)
--AND
--(
    --CHARINDEX('','' + [WorkOrder].DepartmentId + '','',@DepartmentId,1) > 0
--)
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language')
END

-------------------------------------------------------------------------------
-- Comment - Department - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@DepartmentId', 'U', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType = ''OBJ'' AND EntityId LIKE ''%#%'' AND SUBSTRING(EntityId, charindex (''#'', EntityId)+1, LEN(EntityId)) IN (@OrganizationId, ''*'') 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
UNION
--Work order comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
INNER JOIN [UserDepartment] u
ON [WorkOrder].DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE
(
	[WorkOrder].OrganizationId=@OrganizationId OR
	[WorkOrder].OrganizationId=''*''
)
--AND
--(
--	CHARINDEX('','' + [WorkOrder].DepartmentId + '','',@DepartmentId,1) > 0
--)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
UNION
--Equipment History Closing Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
WHERE
(
	[EquipmentHistory].OrganizationId=@OrganizationId OR
	[EquipmentHistory].OrganizationId=''*''
)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
UNION
--Activity Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
INNER JOIN [UserDepartment] u
ON [WorkOrder].DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE
(
    [WorkOrder].OrganizationId=@OrganizationId OR
    [WorkOrder].OrganizationId=''*''
)
--AND
--(
--    CHARINDEX('','' + [WorkOrder].DepartmentId + '','',@DepartmentId,1) > 0
--)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language')
END

-------------------------------------------------------------------------------
-- Comment - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@EmployeeId', 'I', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6), @EmployeeId nvarchar(15),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT DISTINCT [Comment].*
FROM [Comment] 
INNER JOIN [WorkOrder] on Comment.EntityId = WorkOrder.EquipmentId + ''#'' + WorkOrder.EquipmentOrganizationId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId 
WHERE
(
      ([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
  AND ([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
  AND EntityType = ''OBJ''
)
AND 
(
  ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
  OR
  ([WorkOrder].InsertTimestamp > @sync_last_received_anchor AND [WorkOrder].InsertTimestamp <= @sync_new_received_anchor)
)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT *
FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)

UNION

--Assigned Work order comments
SELECT DISTINCT [Comment].*
FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId
WHERE
(
  ([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
  AND ([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
  AND EntityType = ''EVNT''
)
AND 
(
  ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
  OR
  ([WorkOrder].InsertTimestamp > @sync_last_received_anchor AND [WorkOrder].InsertTimestamp <= @sync_new_received_anchor)
)

UNION

--Equipment History Closing Comments
SELECT DISTINCT [Comment].*
FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
INNER JOIN WorkOrder on EquipmentHistory.EquipmentId = WorkOrder.EquipmentId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId
WHERE
(
      ([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
  AND ([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
  AND EntityType = ''EVNT''
)
AND 
(
  ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
  OR
  ([WorkOrder].InsertTimestamp > @sync_last_received_anchor AND [WorkOrder].InsertTimestamp <= @sync_new_received_anchor)
)

UNION

--Activity Comments
SELECT DISTINCT [Comment].*
FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
LEFT OUTER JOIN Schedule ON Activity.WorkOrderId = Schedule.WorkOrderId AND Activity.ActivityId = Schedule.ActivityId AND Schedule.EmployeeId = @EmployeeId
WHERE
(
      ([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
  AND ([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
  AND EntityType = ''EVNT''
)
AND 
(
  ([Comment].InsertTimestamp > @sync_last_received_anchor AND [Comment].InsertTimestamp <= @sync_new_received_anchor)
  OR
  ([WorkOrder].InsertTimestamp > @sync_last_received_anchor AND [WorkOrder].InsertTimestamp <= @sync_new_received_anchor)
)) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language')
END

-------------------------------------------------------------------------------
-- Comment - Employee - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Comment' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Comment','*', '*', '@EmployeeId', 'U', 
'
--declare @OrganizationId nvarchar(4),@DepartmentId nvarchar(6), @EmployeeId nvarchar(15),@sync_last_received_anchor binary(8000),@sync_new_received_anchor binary(8)
SELECT c.* FROM Comment c, (
--Equipment Comments
SELECT DISTINCT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [WorkOrder] on Comment.EntityId = WorkOrder.EquipmentId + ''#'' + WorkOrder.EquipmentOrganizationId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId 
WHERE
	([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND
	([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
AND EntityType = ''OBJ'' 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Task instructions and Planned Maintenance (PPM) 
SELECT [EntityType], [EntityId], [Description], [CommentType], [LineNumber], [Language], [TransactionDate], [TransactionOrganization], [TransactionPassword], [TransactionTimeZone], [TransactionUser], [TransactionId], [TransactionDepartmentId], [TransactionWorkOrderId], [CreatedByName], [CreatedDate], [UpdatedByName], [UpdatedDate], [RecordId], [InsertTimestamp], [UpdateTimestamp], [RowGuid] FROM [Comment] 
WHERE EntityType IN (''PPM'',''TASK'') 
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Assigned Work order comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN WorkOrder ON Comment.EntityId = WorkOrder.WorkOrderId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND
([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Equipment History Closing Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN  [EquipmentHistory] ON [EquipmentHistory].WorkOrderId = [Comment].EntityId
INNER JOIN WorkOrder on EquipmentHistory.EquipmentId = WorkOrder.EquipmentId
LEFT OUTER JOIN Schedule ON WorkOrder.WorkOrderId = Schedule.WorkOrderId AND Schedule.EmployeeId = @EmployeeId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND
([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)

UNION

--Activity Comments
SELECT [Comment].[EntityType], [Comment].[EntityId], [Comment].[Description], [Comment].[CommentType], [LineNumber], [Language], [Comment].[TransactionDate], [Comment].[TransactionOrganization], [Comment].[TransactionPassword], [Comment].[TransactionTimeZone], [Comment].[TransactionUser], [Comment].[TransactionId], [Comment].[TransactionDepartmentId], [Comment].[TransactionWorkOrderId],[Comment].[CreatedByName], [Comment].[CreatedDate], [Comment].[UpdatedByName], [Comment].[UpdatedDate], [Comment].[RecordId], [Comment].[InsertTimestamp], [Comment].[UpdateTimestamp], [Comment].[RowGuid] FROM [Comment] 
INNER JOIN [Activity] on [Activity].WorkOrderId + ''#'' + cast([Activity].ActivityId as varchar(8)) = [Comment].EntityId
INNER JOIN [WorkOrder] ON [WorkOrder].WorkOrderId = [Activity].WorkOrderId
LEFT OUTER JOIN Schedule ON Activity.WorkOrderId = Schedule.WorkOrderId AND Activity.ActivityId = Schedule.ActivityId AND Schedule.EmployeeId = @EmployeeId
WHERE
([WorkOrder].OrganizationId=@OrganizationId OR [WorkOrder].OrganizationId=''*'')
AND
([WorkOrder].AssignedToEmployeeId = @EmployeeId OR Schedule.EmployeeId = @EmployeeId)
AND ([Comment].UpdateTimestamp > @sync_last_received_anchor AND [Comment].UpdateTimestamp <= @sync_new_received_anchor AND [Comment].InsertTimestamp <= @sync_last_received_anchor)
) sub
WHERE c.EntityId = sub.EntityId
AND c.EntityType = sub.EntityType
AND c.LineNumber = sub.LineNumber
AND c.Language = sub.Language')
END


-------------------------------------------------------------------------------
-- Document - Organization - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@OrganizationId', 'I', 
'SELECT DISTINCT d.* 
FROM Document d, WorkOrder w
WHERE 
((d.InsertTimestamp > @sync_last_received_anchor AND d.InsertTimestamp <= @sync_new_received_anchor)
AND
(w.OrganizationId = @OrganizationId or w.OrganizationId = ''*''))
AND 
((d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
OR 
(d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
OR 
(d.EntityId = w.DepartmentId AND d.Entity = ''MRC''))')
END

-------------------------------------------------------------------------------
-- Document - Organization - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@OrganizationId', 'U', 
'SELECT DISTINCT d.* FROM Document d, WorkOrder w
WHERE 
((d.UpdateTimestamp > @sync_last_received_anchor AND d.UpdateTimestamp <= @sync_new_received_anchor AND d.InsertTimestamp <= @sync_last_received_anchor)
AND
(w.OrganizationId = @OrganizationId or w.OrganizationId = ''*''))
AND 
((d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
OR 
(d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
OR 
(d.EntityId = w.DepartmentId AND d.Entity = ''MRC''))')
END

-------------------------------------------------------------------------------
-- Document - Department - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@DepartmentId', 'I', 
'SELECT DISTINCT d.* FROM Document d, WorkOrder w
INNER JOIN [UserDepartment] u
ON w.DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE 
((d.InsertTimestamp > @sync_last_received_anchor AND d.InsertTimestamp <= @sync_new_received_anchor)
AND
(w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')
--AND
--(CHARINDEX('','' + w.DepartmentId + '','',@DepartmentId,1) > 0)
)
AND 
((d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
OR 
(d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
OR 
(d.EntityId = w.DepartmentId AND d.Entity = ''MRC''))')
END

-------------------------------------------------------------------------------
-- Document - Department - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@DepartmentId', 'U', 
'SELECT DISTINCT d.* FROM Document d, WorkOrder w
INNER JOIN [UserDepartment] u
ON w.DepartmentId = u.DepartmentId AND u.UserId = @UserId 
WHERE 
((d.UpdateTimestamp > @sync_last_received_anchor AND d.UpdateTimestamp <= @sync_new_received_anchor AND d.InsertTimestamp <= @sync_last_received_anchor)
AND
(w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')
--AND
--(CHARINDEX('','' + w.DepartmentId + '','',@DepartmentId,1) > 0)
)
AND 
((d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
OR 
(d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
OR 
(d.EntityId = w.DepartmentId AND d.Entity = ''MRC''))')
END

-------------------------------------------------------------------------------
-- Document - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@EmployeeId', 'I', 
'SELECT DISTINCT d.* FROM Document d, WorkOrder w
WHERE 
(
	(
		(d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
		AND
		(w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')
		AND 
		(w.AssignedToEmployeeId = @EmployeeId OR w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId))
	)
    OR 
	(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
    OR 
    (d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
    OR 
    (d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
    OR 
    (d.EntityId = w.DepartmentId AND d.Entity = ''MRC'')
)
AND 
(
    (d.InsertTimestamp > @sync_last_received_anchor AND d.InsertTimestamp <= @sync_new_received_anchor) 
    OR
    (w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor)
)')
END

-------------------------------------------------------------------------------
-- Document - Employee - SelectIncrementalUpdatesCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Document' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Document','*', '*', '@EmployeeId', 'U', 
'SELECT DISTINCT d.* FROM Document d, WorkOrder w
WHERE 
((d.UpdateTimestamp > @sync_last_received_anchor AND d.UpdateTimestamp <= @sync_new_received_anchor AND d.InsertTimestamp <= @sync_last_received_anchor)
AND
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId or w.OrganizationId = ''*''))
OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*''))))
AND 
((d.EntityId = w.WorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.EquipmentId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''OBJ'')
OR 
(d.EntityId = w.ParentWorkOrderId AND d.Entity = ''EVNT'')
OR 
(d.EntityId = w.LocationId + ''#'' + w.EquipmentOrganizationId AND d.Entity = ''LOC'')
OR 
(d.EntityId = w.DepartmentId AND d.Entity = ''MRC''))')
END

-------------------------------------------------------------------------------
-- Activity - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Activity' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Activity','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM Activity a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- Labor - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Labor' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Labor','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM Labor a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- Schedule - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Schedule' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Schedule','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM Schedule a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- Material - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'Material' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('Material','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM Material a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- WorkOrderUdf - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'WorkOrderUdf' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I')
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('WorkOrderUdf','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM WorkOrderUdf a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- InspectionPoint - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'InspectionPoint' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I')
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('InspectionPoint','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM InspectionPoint a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.WorkOrderId
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

-------------------------------------------------------------------------------
-- CustomFieldValue - Employee - SelectIncrementalInsertsCommand
-------------------------------------------------------------------------------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = 'CustomFieldValue' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I')
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('CustomFieldValue','*', '*', '@EmployeeId', 'I', 
'SELECT a.*
FROM CustomFieldValue a
INNER JOIN WorkOrder w ON w.WorkOrderId = a.EntityId AND a.SystemEntity = ''EVNT''
WHERE 
((w.AssignedToEmployeeId = @EmployeeId AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')) 
  OR
(w.WorkOrderId IN (SELECT WorkOrderId FROM Schedule WHERE EmployeeId = @EmployeeId) AND (w.OrganizationId = @OrganizationId OR w.OrganizationId = ''*'')))
AND 
((a.InsertTimestamp > @sync_last_received_anchor AND a.InsertTimestamp <= @sync_new_received_anchor) 
  OR
(w.InsertTimestamp > @sync_last_received_anchor AND w.InsertTimestamp <= @sync_new_received_anchor))')
END

/*--------TEMPLATE----------
IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@OrganizationId', 'I', '')
END

IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@OrganizationId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@OrganizationId', 'U', '')
END

IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@DepartmentId', 'I', '')
END

IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@DepartmentId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@DepartmentId', 'U', '')
END

IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'I') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@EmployeeId', 'I', '')
END

IF NOT EXISTS(SELECT * FROM DeviceSyncQuery WHERE TableName = '{TABLENAME}' AND UserGroupId = '*' AND UserId = '*' AND DeviceFilterType = '@EmployeeId' AND QueryType = 'U') 
BEGIN
INSERT INTO DeviceSyncQuery (TableName,UserGroupId,UserId,DeviceFilterType,QueryType,QueryText)
VALUES ('{TABLENAME}','*', '*', '@EmployeeId', 'U', '')
END
*/

-- =============================================
-- Set permissions on the database for the configured service user
-- =============================================

IF NOT EXISTS (SELECT * FROM master.dbo.syslogins WHERE loginname = N'$(Login)')
CREATE LOGIN [$(Login)] FROM WINDOWS
GO
GRANT CONNECT TO [$(Login)]
GO
BEGIN TRY
EXEC sp_addrolemember N'db_owner', N'$(Login)'
END TRY
BEGIN CATCH
END CATCH
GO


